/*
 * This file is part of Cleanflight.
 *
 * Cleanflight is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Cleanflight is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Cleanflight.  If not, see <http://www.gnu.org/licenses/>.
 */

#pragma once

#define TARGET_BOARD_IDENTIFIER "MIF3"

#define LED0_PIN                PB5

#define BEEPER                  PC14

#define USE_GYRO
#define USE_GYRO_MPU6050
#define GYRO_MPU6050_ALIGN      CW270_DEG

#define USE_ACC
#define USE_ACC_MPU6050
#define ACC_MPU6050_ALIGN       CW270_DEG

#define USE_EXTI
#define MPU_INT_EXTI            PA13
#define USE_MPU_DATA_READY_SIGNAL

#define USE_VCP

#define USE_UART1
#define UART1_TX_PIN            PA9
#define UART1_RX_PIN            PA10

#define USE_UART2
#define UART2_TX_PIN            PB3
#define UART2_RX_PIN            PB4

//#define UART3_TX_PIN            PB10

#define SERIAL_PORT_COUNT       3

#define USE_I2C
#define USE_I2C_DEVICE_1
#define I2C_DEVICE             (I2CDEV_1)
#define I2C1_SDA               PA14
#define I2C1_SCL               PA15

#define USE_SPI

#define USE_SPI_DEVICE_1
#define SPI1_NSS_PIN            PA4
#define SPI1_SCK_PIN            PA5
#define SPI1_MISO_PIN           PA6
#define SPI1_MOSI_PIN           PA7

#define USE_SPI_DEVICE_2
#define SPI2_NSS_PIN            PB12
#define SPI2_SCK_PIN            PB13
#define SPI2_MISO_PIN           PB14
#define SPI2_MOSI_PIN           PB15

#define USE_SDCARD
#define USE_SDCARD_SPI2

#define SDCARD_SPI_INSTANCE                 SPI2
#define SDCARD_SPI_CS_PIN                   SPI2_NSS_PIN

// SPI2 is on the APB1 bus whose clock runs at 36MHz. Divide to under 400kHz for init:
#define SDCARD_SPI_INITIALIZATION_CLOCK_DIVIDER 128
// // Divide to under 25MHz for normal operation:
#define SDCARD_SPI_FULL_SPEED_CLOCK_DIVIDER     2

#define SDCARD_DMA_CHANNEL_TX               DMA1_Channel5
#define SDCARD_DMA_CHANNEL_TX_COMPLETE_FLAG DMA1_FLAG_TC5

#define USE_ADC
#define ADC_INSTANCE            ADC1
#define VBAT_ADC_PIN            PA0
#define CURRENT_METER_ADC_PIN   PA1

// Can be used on motor 1 / 2 pads (A02 / A03):
#define EXTERNAL1_ADC_PIN       NONE
#define RSSI_ADC_PIN            NONE

#define DEFAULT_VOLTAGE_METER_SOURCE VOLTAGE_METER_ADC
#define DEFAULT_CURRENT_METER_SOURCE CURRENT_METER_ADC

#define USE_RX_SPI
#define RX_SPI_INSTANCE         SPI1
#define RX_NSS_GPIO_CLK_PERIPHERAL   RCC_APB2Periph_GPIOA


#define USE_RX_FRSKY_SPI_D
#define USE_RX_FRSKY_SPI_X
#define DEFAULT_RX_FEATURE      FEATURE_RX_SPI	
#define RX_SPI_DEFAULT_PROTOCOL RX_SPI_FRSKY_X
#define USE_RX_FRSKY_SPI_TELEMETRY

#define RX_NSS_PIN               SPI1_NSS_PIN
#define RX_SCK_PIN               SPI1_SCK_PIN
#define RX_MISO_PIN              SPI1_MISO_PIN
#define RX_MOSI_PIN              SPI1_MOSI_PIN

#define RX_FRSKY_SPI_GDO_0_PIN   PB0

#define RX_FRSKY_SPI_LED_PIN     PB6


#define USE_RX_FRSKY_SPI_PA_LNA

#define RX_FRSKY_SPI_TX_EN_PIN   PB1
#define RX_FRSKY_SPI_LNA_EN_PIN  PB11


#define USE_RX_FRSKY_SPI_DIVERSITY

#define RX_FRSKY_SPI_ANT_SEL_PIN PB2


#define BINDPLUG_PIN             PC13

#define USE_SERIAL_4WAY_BLHELI_INTERFACE
#define USE_ESCSERIAL
#define ESCSERIAL_TIMER_TX_HARDWARE 0

#define DEFAULT_FEATURES        (FEATURE_AIRMODE | FEATURE_TELEMETRY)

#define TARGET_IO_PORTA         0xffff
#define TARGET_IO_PORTB         0xffff
#define TARGET_IO_PORTC         (BIT(13)|BIT(14)|BIT(15))
#define TARGET_IO_PORTF         (BIT(0)|BIT(1)|BIT(4))

#define USABLE_TIMER_CHANNEL_COUNT 6
#define USED_TIMERS             (TIM_N(1) | TIM_N(2) | TIM_N(3) | TIM_N(8) | TIM_N(15))
